## Précision/Tolérance et relations spatiales dans Qualigéo

La précision et la tolérance sont exploitées pour assurer la vérification de contraintes de relations spatiales et de construction. La précision opère un arrondi sur les coordonnées des entités, alors que la tolérance permet la création d’une zone tampon sur les entités de référence afin d’ignorer ou accepter des erreurs éventuelles des digitalisation.

### Précision et relation spatiale

La précision détermine la précision de stockage des coordonnées des entités. Elle permet d’ignorer des écarts minimes dus au format de stockage des données.

Par exemple, dans le cas de données en Lambert, une précision de 1 correspond à une précision décimétrique c’est à dire que les coordonnées sont arrondies à un chiffre après la virgule. Une précision de 2 correspond à une précision centimétrique et ainsi de suite. Aucun arrondi n’est effectué si aucune précision n’est paramétrée (précision =0).

#### Exemple

L’exemple ci-dessous présente le point 1 et le point 2 :

* **Point 1 (1,1221111 1,1221111)**
* **Point 2 (1,131515 1,1351515)**

Dans le cas d’une précision décimétrique, ces deux points sont identiques, alors que dans le cas d’une précision centimétriques, ces derniers sont distincts.

<style type="text/css">
.tg  {border-collapse:collapse;border-spacing:0;}
.tg td{border-color:black;border-style:solid;border-width:1px;font-family:Arial, sans-serif;font-size:14px;
  overflow:hidden;padding:10px 20px;word-break:normal;}
.tg th{border-color:black;border-style:solid;border-width:1px;font-family:Arial, sans-serif;font-size:14px;
  font-weight:normal;overflow:hidden;padding:10px 20px;word-break:normal;}
.tg .tg-o6tx{background-color:#eae8e8;border-color:#d6d6d6;text-align:left;vertical-align:top}
.tg .tg-0pn5{background-color:#923288;border-color:#d6d6d6;color:#ffffff;text-align:left;vertical-align:top}
.tg .tg-avj4{border-color:#d6d6d6;text-align:left;vertical-align:top}
</style>
<table class="tg">
  <tr>
    <th class="tg-0pn5"></th>
    <th class="tg-0pn5">Précision = 1</th>
    <th class="tg-0pn5">Précision = 2</th>
  </tr>
  <tr>
    <td class="tg-0pn5">Coordonnées X et Y du point 1</td>
    <td class="tg-avj4">1,1</td>
    <td class="tg-avj4">1,12</td>
  </tr>
  <tr>
    <td class="tg-0pn5">Coordonnées X et Y du point 2</td>
    <td class="tg-o6tx">1,1</td>
    <td class="tg-o6tx">1,13</td>
  </tr>
  <tr>
    <td class="tg-0pn5">Représentation graphique</td>
    <td class="tg-avj4"><img src="https://gitlab.veremes.net/Documentation/doc_qualigeo/raw/7f2030131fba9980de19c3ec9b90539ca44bfb19/Ressources/Images/precision1.png" alt="Image" width="400" height="236"></td>
    <td class="tg-avj4"><img src="https://gitlab.veremes.net/Documentation/doc_qualigeo/raw/4007b95a1caff32811de36d836d86c602b95fd4d/Ressources/Images/precision2.png" alt="Image" width="400" height="244"></td>
  </tr>
  <tr>
    <td class="tg-0pn5">Les points sont-ils disjoints ?</td>
    <td class="tg-o6tx">Non<br></td>
    <td class="tg-o6tx">Oui</td>
  </tr>
  <tr>
    <td class="tg-0pn5">Les points sont-ils égaux ?</td>
    <td class="tg-avj4">Oui</td>
    <td class="tg-avj4">Non</td>
  </tr>
</table>


==> Erreur retournée E0053

### Tolérance et relation spatiale

Exprimée en unité terrain, la tolérance permet d’ignorer des erreurs en créant une zone tampon (positive ou négative) sur le type d’entité de référence. Le type d’entité à contrôler peut ainsi valider la contrainte de relation spatiale de type "A l’intérieur" qu’il n’aurait pas satisfait sans l’agrandissement ou le rétrécissement opéré par la tolérance.

#### Exemple

Un BATIMENT doit toujours être à l’intérieur d’une PARCELLE. Il est nécessaire de définir une tolérance afin d’ignorer l’erreur de digitalisation illustrée ci-dessous. Via la tolérance, les décalages observés sont acceptés et aucune erreur n’est générée. La tolérance est opérée sur les types d’entité de référence et est exprimée en unité terrain.

![](../Ressources/Images/tolerance_724x209.png)

Ce cas de figure ne sera pas considéré comme une erreur si une tolérance de 0.01 est définie lors de la définition du schéma correspondant.

### Tolérance et contrainte de construction

La tolérance peut être exploitée pour vérifier la règle de construction "Appui sur segment ou partie de segment" (tous les segments du type d’entité à contrôler ne doivent pas croiser ou être contenus dans le type d’entité de référence). En effectuant une zone tampon sur l’entité de référence, une erreur de construction est générée pour chaque segment de l’ entité qui intersecte la référence agrandie par la zone tampon.

#### Exemple

<table style="width: 100%;margin-left: 0;margin-right: auto;mc-table-style: url(’../Ressources/TableStyles/Basic.css’);" class="TableStyle_Basic" cellspacing="0">
<col style="width: 317px;" />
<col />
<tbody>
                        <tr>
                            <td class="TableStyle_Basic_Body_0_0_RowSep_ColSep">Tolerance = 0 </td>
                            <td class="TableStyle_Basic_Body_0_0_RowSep_ColEnd">Tolerance = 1</td>
                        </tr>
                        <tr>
                            <td class="TableStyle_Basic_Body_0_0_RowSep_ColSep">
                                <img src="..\_images/construction_tolerance1_267x149.png" style="width: 267;height: 149;" />
                            </td>
                            <td class="TableStyle_Basic_Body_0_0_RowSep_ColEnd">
                                <img src="..\_images/constructipn_tolerance2_289x172.png" style="width: 289;height: 172;" />
                            </td>
                        </tr>
                        <tr>
                            <td class="TableStyle_Basic_Body_0_0_RowEnd_ColSep">Aucun segment en erreur </td>
                            <td class="TableStyle_Basic_Body_0_0_RowEnd_ColEnd">Segments [AB], [AD] et [DC] en erreur (E0052)</td>
                        </tr>
                    </tbody>
                </table>
